# Sunshine

**django-sunshine** is a Bootstrap-based boilerplate for building modern Django websites.

## Installation

**django-sunshine** is available on [PyPI](https://pypi.org/project/django-sunshine/) and can be installed using pip:

```
pip install django-sunshine
```

## Development

1. Install Python requirements
2. Run migration `python manage.py migrate`
3. Create super user with `python manage.py createsuperuser`
4. View front-end page on browser: https://localhost:8000
   - Back-end page for admin is available at: http://localhost:8000/sunshine/home/

## License

**django-sunshine** package is licensed under MIT License.
The following packages are included:

- [jQuery 3.5.1](https://jquery.org/license/) - MIT License
- [Bootstrap 4.6](https://getbootstrap.com/docs/4.6/getting-started/introduction/) - MIT License
- [Vue 2.6.12](https://vuejs.org/) - MIT License
- [sb-admin-2](https://github.com/StartBootstrap/startbootstrap-sb-admin-2) - MIT License
- [jquery-easing](http://gsgd.co.uk/sandbox/jquery/easing) - MIT License
- [Font Awesome Free 5.13.1](https://fontawesome.com) - [Icons -CC BY 4.0 -Fonts: SIL OFL 1.1 - Code: MIT License](https://fontawesome.com/license/free)
